Add verify-art-runtime usage to dex2oat
Bug: 27688793
(cherry picked from commit c6068709a482065d6f5426640f1c9316797508e3)
Change-Id: Idcf6b8023a15c816168ce42456d2bd7b463d0951
diff --git a/dex2oat/dex2oat.cc b/dex2oat/dex2oat.cc
index a5d0c27..2981011 100644
--- a/dex2oat/dex2oat.cc
+++ b/dex2oat/dex2oat.cc
@@ -255,6 +255,7 @@
UsageError("");
UsageError(" --compiler-filter="
"(verify-none"
+ "|verify-at-runtime"
"|interpret-only"
"|space"
"|balanced"
@@ -287,8 +288,8 @@
UsageError("");
UsageError(" --num-dex-methods=<method-count>: threshold size for a small dex file for");
UsageError(" compiler filter tuning. If the input has fewer than this many methods");
- UsageError(" and the filter is not interpret-only or verify-none, overrides the");
- UsageError(" filter to use speed");
+ UsageError(" and the filter is not interpret-only or verify-none or verify-at-runtime, ");
+ UsageError(" overrides the filter to use speed");
UsageError(" Example: --num-dex-method=%d", CompilerOptions::kDefaultNumDexMethodsThreshold);
UsageError(" Default: %d", CompilerOptions::kDefaultNumDexMethodsThreshold);
UsageError("");
@@ -1449,8 +1450,8 @@
}
/*
* If we're not in interpret-only or verify-none mode, go ahead and compile small applications.
* Don't bother to check if we're doing the image.
*/
if (!IsBootImage() &&
compiler_options_->IsCompilationEnabled() &&
@@ -1449,8 +1450,8 @@
}
/*
- * If we're not in interpret-only or verify-none mode, go ahead and compile small applications.
- * Don't bother to check if we're doing the image.
+ * If we're not in interpret-only or verify-none or verify-at-runtime mode, go ahead and
+ * compile small applications. Don't bother to check if we're doing the image.
*/
if (!IsBootImage() &&